@@ -1,4 +1,4 @@
-define(['splunkjs/mvc/simplexml/element/chart', '../viz/viz'], function(
+define(['splunkjs/mvc/simplexml/element/chart', '../viz/viz'], function (
   ChartElement,
   Viz
 ) {
@@ -22,7 +22,7 @@ define(['splunkjs/mvc/simplexml/element/chart', '../viz/viz'], function(
             'charting.chart.stackMode': extraParams.stackMode || 'default',
             resizable: true,
             managerid: `${id}Search`,
-            el: $(`#${attachedElement}`)
+            el: $(`#${attachedElement}`),
           },
           { tokens: true, tokenNamespace: 'submitted' }
         ).render(),
